package
Version:
v0.0.0-...-541196a
Opens a new window with list of versions in this module.
Published: Mar 1, 2023
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DeviceService interface {
GetDevice(mac string) (*Device, error)
UpdateDevice(mac, firmwareType, firmwareVersion string) error
}
type FirmwareService interface {
GetFirmware(firmwareType, firmwareVersion string) (*Firmware, error)
GetFirmwareByType(firmwareType string) (FirmwareList, error)
GetFirmwareData(firmwareType, firmwareVersion string) ([]byte, error)
}
type Updater interface {
Update(mac, currentType, currentVersion string) ([]byte, error)
}
Source Files
¶
Directories
¶
Code generated by counterfeiter.
|
Code generated by counterfeiter. |
Click to show internal directories.
Click to hide internal directories.